<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>ExLayerCustomProperty</name>
    <message>
        <location filename="../ExLayerCustomProperty.js" line="+43"/>
        <source>Added custom property &apos;MyCustomProperty&apos; to layer &apos;0&apos;.</source>
        <translation>Dodana prilagojena lasnost &apos;MyCustomProperty&apos; na plast 0.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Add Custom Property to a Layer</source>
        <translation>Dodaj prilagojeno lasnost na plast</translation>
    </message>
    <message>
        <source>Add custom property to a layer</source>
        <translation type="vanished">Dodaj prilagojeno lasnost na plast</translation>
    </message>
</context>
</TS>
